@@ -3,7 +3,13 @@ from opnsense_cli.api.plugin.haproxy import Settings, Service
 
 
 class HaproxyResolverFacade(HaproxyFacade):
+    jsonpath_base = '$.haproxy.resolvers.resolver'
+    uuid_resolver_map = {
+    }
+
     def __init__(self, settings_api: Settings, service_api: Service):
+        super().__init__()
+        self._complete_model_data_cache = None
         self._settings_api = settings_api
         self._service_api = service_api
 
@@ -16,12 +22,7 @@ class HaproxyResolverFacade(HaproxyFacade):
         return resolver
 
     def _get_resolvers_list(self):
-        complete_model_data = self._settings_api.get()
-        jsonpath_base = '$.haproxy.resolvers.resolver'
-        uuid_resolver_map = {
-        }
-
-        return self._api_mutable_model_get(complete_model_data, jsonpath_base, uuid_resolver_map)
+        return self._api_mutable_model_get(self._complete_model_data, self.jsonpath_base, self.uuid_resolver_map)
 
     def create_resolver(self, json_payload: dict):
         result = self._settings_api.addresolver(json=json_payload)
